# Do not check any files in doc or src for requires
%define __requires_exclude_from ^(%{_datadir}|%{_libdir})/%{name}/(doc|src)/.*$

Summary:	A tool for building identical machine images
Name:		packer
Version:	0.4.0
Release:	%mkrel 5
License:	MPLv2.0
Group:		Emulators
Url:		http://www.packer.io/
Source0:        https://github.com/mitchellh/packer/archive/v%{version}.tar.gz
# Building requires the git repo to be present, so we cannot use the tarballs
# directly. Must download and repack the full git repo as a tarball instead.

BuildRequires:	golang >= 1.1
BuildRequires:	git
BuildRequires:	gox
BuildRequires:	golang(code.google.com/p/go.crypto) >= 0.20131031
BuildRequires:	golang(github.com/mitchellh/goamz) >= 0.20131119
BuildRequires:	golang(github.com/mitchellh/go-fs)
BuildRequires:	golang(github.com/mitchellh/go-vnc)
BuildRequires:	golang(github.com/mitchellh/iochan)
BuildRequires:	golang(github.com/mitchellh/mapstructure)
BuildRequires:	golang(github.com/mitchellh/multistep)
BuildRequires:	golang(github.com/mitchellh/osext)
BuildRequires:	golang(github.com/mitchellh/panicwrap)
BuildRequires:	golang(github.com/racker/perigee)
BuildRequires:	golang(github.com/rackspace/gophercloud) >= 0.20131025
BuildRequires:	golang(github.com/ActiveState/tail)
BuildRequires:	golang(github.com/howeyc/fsnotify)
BuildRequires:	golang(launchpad.net/tomb)

%description
Packer is a tool for building identical machine images for multiple platforms
from a single source configuration.

Packer is lightweight, runs on every major operating system, and is highly
performant, creating machine images for multiple platforms in parallel. Packer
comes out of the box with support for creating AMIs (EC2), VMware images, and
VirtualBox images. Support for more platforms can be added via plugins.

The images that Packer creates can easily be turned into Vagrant boxes.

%prep
%setup -cT
# For building go binaries we must install the tarballed git repo into the
# appropriate src directory
mkdir -p %{_builddir}/%{name}-%{version}/src/github.com/mitchellh/
cd %{_builddir}/%{name}-%{version}/src/github.com/mitchellh/
tar xzf %{SOURCE0}

# Symlink the go lib build dependencies to the build directory
%define buildgosrc %{_builddir}/%{name}-%{version}/src
mkdir -p %{buildgosrc}/github.com/{mitchellh,racker,rackspace,ActiveState}
mkdir -p %{buildgosrc}/github.com/howeyc
mkdir -p %{buildgosrc}/code.google.com/p
mkdir -p %{buildgosrc}/launchpad.net/tomb
ln -sv %{gopath}/src/github.com/mitchellh/* %{buildgosrc}/github.com/mitchellh/
ln -sv %{gopath}/src/github.com/racker/* %{buildgosrc}/github.com/racker/
ln -sv %{gopath}/src/github.com/rackspace/* %{buildgosrc}/github.com/rackspace/
ln -sv %{gopath}/src/code.google.com/p/* %{buildgosrc}/code.google.com/p/
ln -sv %{gopath}/src/github.com/ActiveState/* \
  %{buildgosrc}/github.com/ActiveState/
ln -sv %{gopath}/src/github.com/howeyc/* %{buildgosrc}/github.com/howeyc/
ln -sv %{gopath}/src/launchpad.net/tomb/* %{buildgosrc}/launchpad.net/tomb/

%build
# set the GOPATH so that internal dependencies are automatically downloaded to
# the correct location
%define packer_gopath %{_builddir}/%{name}-%{version}
export GOPATH=%{packer_gopath}

# set the GOBIN so compiled files go into the builddir
mkdir -p %{packer_gopath}/bin
export GOBIN=%{packer_gopath}/bin

# Checkout the specific tag in git for the version we are building
cd %{packer_gopath}/src/github.com/mitchellh/packer
%make

%install
mkdir -p %{buildroot}%{_bindir}
%{__install} -m 0755 %{packer_gopath}/bin/packer %{buildroot}%{_bindir}/packer

# Rename other binaries so they are called correctly
cd %{packer_gopath}/bin/
for binary in `ls -1 * | grep -v packer`; do
    %{__install} -m 0755 %{packer_gopath}/bin/$binary %{buildroot}%{_bindir}/packer-$binary;
done 

%files
%{_bindir}/packer
%{_bindir}/packer-*


%changelog
* Wed Jul 20 2016 pterjan <pterjan> 0.4.0-5.mga6
+ Revision: 1042917
- Extract debuginfo
- Use gopath macro from golang package

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.4.0-4.mga5
+ Revision: 744649
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.4.0-3.mga5
+ Revision: 683308
- Mageia 5 Mass Rebuild

* Sat Dec 21 2013 thatsamguy <thatsamguy> 0.4.0-2.mga4
+ Revision: 559473
+ rebuild (emptylog)

* Thu Nov 21 2013 thatsamguy <thatsamguy> 0.4.0-1.mga4
+ Revision: 552159
- new version 0.4.0

* Wed Nov 06 2013 thatsamguy <thatsamguy> 0.3.11-1.mga4
+ Revision: 549777
- update to 0.3.11
- update to v0.3.10
-build tarball version of source git repo
-combine binary rename into loop
- fix naming of helper binaries
- fix build env gopath and gobin
- imported package packer

